[Python-checkins] r87096 - in python/branches/release27-maint: Lib/email/message.py

r.david.murray python-checkins at python.org
Mon Dec 6 19:45:46 CET 2010


Author: r.david.murray
Date: Mon Dec  6 19:45:46 2010
New Revision: 87096

Log:
Merged revisions 85130 via svnmerge from 
svn+ssh://pythondev@svn.python.org/python/branches/py3k

........
  r85130 | r.david.murray | 2010-09-30 22:08:02 -0400 (Thu, 30 Sep 2010) | 2 lines
  
  Fix a couple spelling errors in comments and delete redundant __len__ def.
........


Modified:
   python/branches/release27-maint/   (props changed)
   python/branches/release27-maint/Lib/email/message.py

Modified: python/branches/release27-maint/Lib/email/message.py
==============================================================================
--- python/branches/release27-maint/Lib/email/message.py	(original)
+++ python/branches/release27-maint/Lib/email/message.py	Mon Dec  6 19:45:46 2010
@@ -97,7 +97,7 @@
     objects, otherwise it is a string.
 
     Message objects implement part of the `mapping' interface, which assumes
     there is exactly one occurrance of the header per message.  Some headers
     do in fact appear multiple times (e.g. Received) and for those headers,
     you must use the explicit API to set or get all the headers.  Not all of
     the mapping methods are implemented.
@@ -286,7 +286,7 @@
         Return None if the header is missing instead of raising an exception.
 
         Note that if the header appeared multiple times, exactly which
-        occurrance gets returned is undefined.  Use get_all() to get all
+        occurrence gets returned is undefined.  Use get_all() to get all
         the values matching a header field name.
         """
         return self.get(name)
@@ -97,7 +97,7 @@
 
     Message objects implement part of the `mapping' interface, which assumes
-    there is exactly one occurrance of the header per message.  Some headers
+    there is exactly one occurrence of the header per message.  Some headers
     do in fact appear multiple times (e.g. Received) and for those headers,
     you must use the explicit API to set or get all the headers.  Not all of


More information about the Python-checkins mailing list